@@ -6,7 +6,7 @@ sub check {
   my $params = shift;
   
   # Do not run an package inventory if there is the --nosoft parameter
-  return if ($params->{params}->{nosoftware});
+  return if ($params->{config}->{nosoftware});
    
   1;
 }
